==> webtrees-2.1.16.zip: webtrees/resources/lang/mk/messages.php <==
<?php

return array (
  ' but the details are unknown' => ' no detalite se nepoznati',
  ' in ' => ' vo ',
  '%1$s does not exist. Did you mean %2$s?' => '%1$s ne postoi. Dali mislevte na %2$s?',
  '%1$s does not have a link back to %2$s.' => '%1$s nema link, nazad do %2$s.',
  '%1$s file was extracted in %2$s seconds.' . "\0" . '%1$s files were extracted in %2$s seconds.' => '%1$s podatok beše izvlečena za %2$s sekundi.' . "\0" . '%1$s podatocite beše izvlečena za %2$s sekundi.',
  '%1$s is a %2$s but a %3$s is expected.' => '%1$s e %2$s, no se očekuva %3$s.',
  '%1$s × %2$s' => '%1$s × %2$s',
  'FEMALE%1$s × %2$s' => '%1$s × %2$s',
  'MALE%1$s × %2$s' => '%1$s × %2$s',
  '%1$s × %2$s pixels' => '%1$s × %2$s pixels',
  '%1$s: %2$s' => '%1$s: %2$s',
  '%1$s–%2$s' => '%1$s–%2$s',
  '%1$s’s %2$s' => '%1$s’s %2$s',
  '%H:%i:%s' => '%H:%i:%s',
  '%j %F %Y' => '%j %F %Y',
  '%s BCE' => '%s BCE',
  '%s KB' => '%s KB',
  '%s and her ancestors' => '%s i nejzinite predci',
  '%s day' . "\0" . '%s days' => '%s den' . "\0" . '%s denovi',
  '%s month' . "\0" . '%s months' => '%s mesec' . "\0" . '%s meseci',
  '%s year' . "\0" . '%s years' => '%s godina' . "\0" . '%s godini',
  '(%s after death)' => '(%s posle smrtta)',
  '(on the date of death)' => '(na denot na smrtta)',
  'A list of the most popular given names.' => 'Lista so najpopularni iminja.',
  'Add a father' => 'Dodadi tatko',
  'Female pedigreeAdopted' => 'Posvoen',
  'Male pedigreeAdopted' => 'Posvoeno',
  'All facts and events' => 'Site fakti i nastani',
  'Abbreviation for AprilApr' => 'Apr',
  'GENITIVEApril' => 'April',
  'INSTRUMENTALApril' => 'April',
  'LOCATIVEApril' => 'April',
  'NOMINATIVEApril' => 'April',
  'MALEAttendant' => 'Pridruzhnik',
  'MALEAttending' => 'Prisustvo',
  'Abbreviation for AugustAug' => 'Avg',
  'GENITIVEAugust' => 'Avgust',
  'INSTRUMENTALAugust' => 'Avgust',
  'LOCATIVEAugust' => 'Avgust',
  'NOMINATIVEAugust' => 'Avgust',
  'Average number of children per family' => 'Prosechen broj deca po semejstvo',
  'Birth' => 'Ragjanje',
  'Female pedigreeBirth' => 'Ragjanje',
  'Male pedigreeBirth' => 'Ragjanje',
  'PedigreeBirth' => 'Ragjanje',
  'Birth name' => 'Rodeno ime',
  'Birth of a daughter' => 'Ragjanje na kjerka',
  'Birth of a son' => 'Ragjanje na sin',
  'Births' => 'Ragjanja',
  'NOMINATIVEBrumaire' => 'Brumer',
  'Burial of a father' => 'Pogrebuvanje na tatko',
  'Burial of a grandfather' => 'Pogrebuvanje na dedo',
  'MALEBuyer' => 'Kupuvach',
  'Cause of death' => 'Prichina za smrtta',
  'Date of birth' => 'Den na ragjanje',
  'Date of death' => 'Datum na smrt',
  'Day' => 'Den',
  'Day not set' => 'Denot ne e odreden',
  'Death' => 'Smrt',
  'Death of a father' => 'Smrt na tatko',
  'Death of a grandfather' => 'Smrt na dedo',
  'Death of a mother' => 'Smrt na majkata',
  'Deaths' => 'Pochinati',
  'Abbreviation for DecemberDec' => 'Dek',
  'GENITIVEDecember' => 'Dekemvri',
  'INSTRUMENTALDecember' => 'Dekemvri',
  'LOCATIVEDecember' => 'Dekemvri',
  'NOMINATIVEDecember' => 'Dekemvri',
  'Edit the gender' => 'Izmenigo polot',
  'Events of close relatives' => 'Nastani na bliski rodnini',
  'Extra information' => 'Dopolnitelni informacii',
  'Facts and events' => 'Fakti i nastani',
  'Family' => 'Semejstvo',
  'Family navigator' => 'Semeen navigator',
  'Family with parents' => 'Semejstvo so roditeli',
  'Father’s age' => 'Vozrast na tatkoto',
  'Father’s family with %s' => 'Semejstvoto na tatkoto so %s',
  'Father’s family with an unknown individual' => 'Semejstvoto na tatkoto so nepoznata lichnost',
  'Abbreviation for FebruaryFeb' => 'Fev',
  'GENITIVEFebruary' => 'Fevruari',
  'INSTRUMENTALFebruary' => 'Fevruari',
  'LOCATIVEFebruary' => 'Fevruari',
  'NOMINATIVEFebruary' => 'Fevruari',
  'Females' => 'Zheni',
  'NOMINATIVEFloreal' => 'Florealen',
  'For technical support or genealogy questions contact %s.' => 'Za tehnichka poddrshka ili genealoshki prashanja kontaktirajte go na %s.',
  'Forgot password?' => 'Zaboravena lozinka?',
  'Female pedigreeFoster' => 'Staratel',
  'Male pedigreeFoster' => 'Staratel',
  'French' => 'Francuski',
  'Fri' => 'Pet',
  'Friday' => 'Petok',
  'NOMINATIVEFrimaire' => 'Frimer',
  'NOMINATIVEFructidor' => 'Fuctidoren',
  'Gender' => 'Pol',
  'NOMINATIVEGerminal' => 'Germinalen',
  'Given names' => 'Ime',
  'Gregorian' => 'Gregorianski',
  'Hide from everyone' => 'Sokri od sekogo',
  'Hijri' => 'Hidjretski',
  'Individuals' => 'Poedinci',
  'Interactive tree' => 'Interaktivno steblo',
  'Interactive tree of %s' => 'Interaktivno steblo na %s',
  'Invalid date' => 'pogreshen datum',
  'Jalali' => 'Jalali',
  'Abbreviation for JanuaryJan' => 'Jan',
  'GENITIVEJanuary' => 'Januari',
  'INSTRUMENTALJanuary' => 'Januari',
  'LOCATIVEJanuary' => 'Januari',
  'NOMINATIVEJanuary' => 'Januari',
  'Jewish' => 'Judski',
  'Abbreviation for JulyJul' => 'Jul',
  'Julian' => 'Julianski',
  'GENITIVEJuly' => 'Juli',
  'INSTRUMENTALJuly' => 'Juli',
  'LOCATIVEJuly' => 'Juli',
  'NOMINATIVEJuly' => 'Juli',
  'Abbreviation for JuneJun' => 'Jun',
  'GENITIVEJune' => 'Juni',
  'INSTRUMENTALJune' => 'Juni',
  'LOCATIVEJune' => 'Juni',
  'NOMINATIVEJune' => 'Juni',
  'Language' => 'Jazik',
  'Languages' => 'Jazik',
  'Latest birth' => 'Najnovo ragjanje',
  'Latest death' => 'Posledna smrt',
  'Link this individual to an existing family as a child' => 'Povrzete ja ova osoba so postoechko semejstvo kako dete',
  'Males' => 'Mazhi',
  'Abbreviation for MarchMar' => 'Mar',
  'GENITIVEMarch' => 'Mart',
  'INSTRUMENTALMarch' => 'Mart',
  'LOCATIVEMarch' => 'Mart',
  'NOMINATIVEMarch' => 'Mart',
  'Abbreviation for MayMay' => 'Maj',
  'GENITIVEMay' => 'Maj',
  'INSTRUMENTALMay' => 'Maj',
  'LOCATIVEMay' => 'Maj',
  'NOMINATIVEMay' => 'Maj',
  'NOMINATIVEMessidor' => 'Messidoren',
  'Mon' => 'Pon',
  'Monday' => 'Ponedelnik',
  'Mother’s family with %s' => 'Semejstvoto na majkata so %s',
  'Mother’s family with an unknown individual' => 'Semejstvoto na majkata so nepoznata lichnost',
  'Name' => 'Ime i prezime',
  'RepositoryName' => 'Ime i prezime',
  'NOMINATIVENivose' => 'Nivos',
  'Note' => 'Zabeleshka',
  'Abbreviation for NovemberNov' => 'Nov',
  'GENITIVENovember' => 'Noemvri',
  'INSTRUMENTALNovember' => 'Noemvri',
  'LOCATIVENovember' => 'Noemvri',
  'NOMINATIVENovember' => 'Noemvri',
  'Number of given names' => 'Broj na dadeni iminja',
  'Abbreviation for OctoberOct' => 'Okt',
  'GENITIVEOctober' => 'Oktomvri',
  'INSTRUMENTALOctober' => 'Oktomvri',
  'LOCATIVEOctober' => 'Oktomvri',
  'NOMINATIVEOctober' => 'Oktomvri',
  'On this day' => 'Na ovoj den',
  'On this day…' => 'Na ovoj den…',
  'Palette' => 'Boja na temata',
  'Place of birth' => 'Mesto na ragjanje',
  'Place of death' => 'Mesto na smrt',
  'NOMINATIVEPluviose' => 'Pluvios',
  'NOMINATIVEPrairial' => 'Prairalen',
  'Privacy policy' => 'Politika za privatnost',
  'Female pedigreeRada' => 'Radah',
  'Male pedigreeRada' => 'Radah',
  'Re-order families' => 'Sortiraj gi semejstvata',
  'Relationship to father' => 'Odnos so tatkoto',
  'Relationship to mother' => 'Relacija so majkata',
  'Request a new password' => 'Pobarajte nova lozinka',
  'Request a new user account' => 'Registriraj se',
  'Sat' => 'Sab',
  'Saturday' => 'Sabota',
  'Female pedigreeSealing' => 'Zagrizhuvach',
  'Male pedigreeSealing' => 'Zapechatuvanje',
  'Abbreviation for SeptemberSep' => 'Sep',
  'GENITIVESeptember' => 'Septemvri',
  'INSTRUMENTALSeptember' => 'Septemvri',
  'LOCATIVESeptember' => 'Septemvri',
  'NOMINATIVESeptember' => 'Septemvri',
  'Shared note' => 'Spodelena zabelehska',
  'Show a privacy policy.' => 'Pokazhete gi pravilata za privatnost.',
  'Show only females.' => 'Prikazhi samo zheni.',
  'Show only males.' => 'Prikazhi samo mazhi.',
  'Show to managers' => 'Pokazhi na manadjeri',
  'Show to members' => 'Pokazhi na chlenovite',
  'Show to visitors' => 'Pokazhi na posetitelite',
  'Sign in' => 'Najavi se',
  'Sign-in and registration' => 'Najavuvanje i registracija',
  'Statistics' => 'Statistika',
  'Sun' => 'Ned',
  'Sunday' => 'Nedela',
  'Surname' => 'Prezime',
  'NOMINATIVEThermidor' => 'Thermidoren',
  'This family tree was last updated on %s.' => 'Ova semejno steblo posleden pat e azhurirano na %s.',
  'This page has been viewed %s time.' . "\0" . 'This page has been viewed %s times.' => 'Ovaa stranica e pregledana %s pat.' . "\0" . 'Ovaa stranica e pregledana %s pati.',
  'Thu' => 'Che',
  'Thursday' => 'Chetvrtok',
  'Top %s given name' . "\0" . 'Top %s given names' => 'Vrvno %s ime' . "\0" . 'Vrvni %s iminja',
  'Top given names' => 'Najmnogu davani iminja',
  'Top surname' => 'Vrvno prezime',
  'Top surnames' => 'Vrvni preziminja',
  'Total given names' => 'Vkupno dadeni iminja',
  'Tue' => 'Vto',
  'Tuesday' => 'Vtornik',
  'unknown genderUnknown' => 'Nepoznato',
  'Username' => 'Korisnichko ime',
  'NOMINATIVEVendemiaire' => 'Vendemier',
  'NOMINATIVEVentose' => 'Ventos',
  'View this day' => 'Prikazhi go ovoj den',
  'View this family' => 'Poglednigo ova semejstvo',
  'View this month' => 'Prikazhigo ovoj mesec',
  'View this year' => 'Prikazhija ova godina',
  'Wed' => 'Sre',
  'Wednesday' => 'Sreda',
  'Welcome to this genealogy website' => 'Dobredojdovte na ovaa web-stranica za genealogija',
  'You can apply for an account using the link below.' => 'Mozhete da aplicirate za smetka koristejkji go linkot podolu.',
  'You need to be an authorized user to access this website.' => 'Treba da bidete ovlasten korisnik za da pristapite do ovaa web-stranica.',
  'about %s' => 'okolu %s',
  'after %s' => 'posle %s',
  'before %s' => 'pred %s',
  'between %s and %s' => 'pomegju %s i %s',
  'birth name' => 'rodeno ime',
  'calculated %s' => 'presmetano %s',
  'estimated %s' => 'proceneto %s',
  'father' => 'tatko',
  'from %s' => 'od %s',
  'from %s to %s' => 'od %s do %s',
  'gender' => 'pol',
  'herself' => 'smata taa',
  'himself' => 'samiot toj',
  'interpreted %s (%s)' => 'protolkuvani %s (%s)',
  'mother' => 'majka',
  'to %s' => 'do %s',
  'father’s brotheruncle' => 'striko/vujko',
  'yes' => 'da',
  'Unknown given name…' => '…',
  'Unknown surname…' => '…',
);

==> webtrees-2.1.26.zip: webtrees/resources/lang/mk/messages.php <==
<?php

return array (
  ' but the details are unknown' => ' no detalite se nepoznati',
  ' in ' => ' vo ',
  '%1$s does not exist. Did you mean %2$s?' => '%1$s ne postoi. Dali mislevte na %2$s?',
  '%1$s does not have a link back to %2$s.' => '%1$s nema link, nazad do %2$s.',
  '%1$s file was extracted in %2$s seconds.' . "\0" . '%1$s files were extracted in %2$s seconds.' => '%1$s podatok beše izvlečena za %2$s sekundi.' . "\0" . '%1$s podatocite beše izvlečena za %2$s sekundi.',
  '%1$s is a %2$s but a %3$s is expected.' => '%1$s e %2$s, no se očekuva %3$s.',
  '%1$s × %2$s' => '%1$s × %2$s',
  'FEMALE%1$s × %2$s' => '%1$s × %2$s',
  'MALE%1$s × %2$s' => '%1$s × %2$s',
  '%1$s × %2$s pixels' => '%1$s × %2$s pixels',
  '%1$s: %2$s' => '%1$s: %2$s',
  '%1$s–%2$s' => '%1$s–%2$s',
  '%1$s’s %2$s' => '%1$s’s %2$s',
  '%H:%i:%s' => '%H:%i:%s',
  '%j %F %Y' => '%j %F %Y',
  '%s BCE' => '%s BCE',
  '%s KB' => '%s KB',
  '%s and her ancestors' => '%s i nejzinite predci',
  '%s day' . "\0" . '%s days' => '%s den' . "\0" . '%s denovi',
  '%s month' . "\0" . '%s months' => '%s mesec' . "\0" . '%s meseci',
  '%s year' . "\0" . '%s years' => '%s godina' . "\0" . '%s godini',
  '(%s after death)' => '(%s posle smrtta)',
  '(on the date of death)' => '(na denot na smrtta)',
  'A list of the most popular given names.' => 'Lista so najpopularni iminja.',
  'Add a father' => 'Dodadi tatko',
  'Female pedigreeAdopted' => 'Posvoen',
  'Male pedigreeAdopted' => 'Posvoeno',
  'All facts and events' => 'Site fakti i nastani',
  'Abbreviation for AprilApr' => 'Apr',
  'GENITIVEApril' => 'April',
  'INSTRUMENTALApril' => 'April',
  'LOCATIVEApril' => 'April',
  'NOMINATIVEApril' => 'April',
  'MALEAttendant' => 'Pridruzhnik',
  'MALEAttending' => 'Prisustvo',
  'Abbreviation for AugustAug' => 'Avg',
  'GENITIVEAugust' => 'Avgust',
  'INSTRUMENTALAugust' => 'Avgust',
  'LOCATIVEAugust' => 'Avgust',
  'NOMINATIVEAugust' => 'Avgust',
  'Average number of children per family' => 'Prosechen broj deca po semejstvo',
  'Birth' => 'Ragjanje',
  'Female pedigreeBirth' => 'Ragjanje',
  'Male pedigreeBirth' => 'Ragjanje',
  'PedigreeBirth' => 'Ragjanje',
  'Birth name' => 'Rodeno ime',
  'Birth of a daughter' => 'Ragjanje na kjerka',
  'Birth of a son' => 'Ragjanje na sin',
  'Births' => 'Ragjanja',
  'NOMINATIVEBrumaire' => 'Brumer',
  'Burial of a father' => 'Pogrebuvanje na tatko',
  'Burial of a grandfather' => 'Pogrebuvanje na dedo',
  'MALEBuyer' => 'Kupuvach',
  'Cause of death' => 'Prichina za smrtta',
  'Date of birth' => 'Den na ragjanje',
  'Date of death' => 'Datum na smrt',
  'Day' => 'Den',
  'Day not set' => 'Denot ne e odreden',
  'Death' => 'Smrt',
  'Death of a father' => 'Smrt na tatko',
  'Death of a grandfather' => 'Smrt na dedo',
  'Death of a mother' => 'Smrt na majkata',
  'Deaths' => 'Pochinati',
  'Abbreviation for DecemberDec' => 'Dek',
  'GENITIVEDecember' => 'Dekemvri',
  'INSTRUMENTALDecember' => 'Dekemvri',
  'LOCATIVEDecember' => 'Dekemvri',
  'NOMINATIVEDecember' => 'Dekemvri',
  'Edit the sex' => 'Izmenigo polot',
  'Events of close relatives' => 'Nastani na bliski rodnini',
  'Extra information' => 'Dopolnitelni informacii',
  'Facts and events' => 'Fakti i nastani',
  'Family' => 'Semejstvo',
  'Family navigator' => 'Semeen navigator',
  'Family with parents' => 'Semejstvo so roditeli',
  'Father’s age' => 'Vozrast na tatkoto',
  'Father’s family with %s' => 'Semejstvoto na tatkoto so %s',
  'Father’s family with an unknown individual' => 'Semejstvoto na tatkoto so nepoznata lichnost',
  'Abbreviation for FebruaryFeb' => 'Fev',
  'GENITIVEFebruary' => 'Fevruari',
  'INSTRUMENTALFebruary' => 'Fevruari',
  'LOCATIVEFebruary' => 'Fevruari',
  'NOMINATIVEFebruary' => 'Fevruari',
  'Females' => 'Zheni',
  'NOMINATIVEFloreal' => 'Florealen',
  'For technical support or genealogy questions contact %s.' => 'Za tehnichka poddrshka ili genealoshki prashanja kontaktirajte go na %s.',
  'Forgot password?' => 'Zaboravena lozinka?',
  'Female pedigreeFoster' => 'Staratel',
  'Male pedigreeFoster' => 'Staratel',
  'French' => 'Francuski',
  'Fri' => 'Pet',
  'Friday' => 'Petok',
  'NOMINATIVEFrimaire' => 'Frimer',
  'NOMINATIVEFructidor' => 'Fuctidoren',
  'NOMINATIVEGerminal' => 'Germinalen',
  'Given names' => 'Ime',
  'Gregorian' => 'Gregorianski',
  'Hide from everyone' => 'Sokri od sekogo',
  'Hijri' => 'Hidjretski',
  'Individuals' => 'Poedinci',
  'Interactive tree' => 'Interaktivno steblo',
  'Interactive tree of %s' => 'Interaktivno steblo na %s',
  'Invalid date' => 'pogreshen datum',
  'Jalali' => 'Jalali',
  'Abbreviation for JanuaryJan' => 'Jan',
  'GENITIVEJanuary' => 'Januari',
  'INSTRUMENTALJanuary' => 'Januari',
  'LOCATIVEJanuary' => 'Januari',
  'NOMINATIVEJanuary' => 'Januari',
  'Jewish' => 'Judski',
  'Abbreviation for JulyJul' => 'Jul',
  'Julian' => 'Julianski',
  'GENITIVEJuly' => 'Juli',
  'INSTRUMENTALJuly' => 'Juli',
  'LOCATIVEJuly' => 'Juli',
  'NOMINATIVEJuly' => 'Juli',
  'Abbreviation for JuneJun' => 'Jun',
  'GENITIVEJune' => 'Juni',
  'INSTRUMENTALJune' => 'Juni',
  'LOCATIVEJune' => 'Juni',
  'NOMINATIVEJune' => 'Juni',
  'Language' => 'Jazik',
  'Languages' => 'Jazik',
  'Latest birth' => 'Najnovo ragjanje',
  'Latest death' => 'Posledna smrt',
  'Link this individual to an existing family as a child' => 'Povrzete ja ova osoba so postoechko semejstvo kako dete',
  'Males' => 'Mazhi',
  'Abbreviation for MarchMar' => 'Mar',
  'GENITIVEMarch' => 'Mart',
  'INSTRUMENTALMarch' => 'Mart',
  'LOCATIVEMarch' => 'Mart',
  'NOMINATIVEMarch' => 'Mart',
  'Abbreviation for MayMay' => 'Maj',
  'GENITIVEMay' => 'Maj',
  'INSTRUMENTALMay' => 'Maj',
  'LOCATIVEMay' => 'Maj',
  'NOMINATIVEMay' => 'Maj',
  'NOMINATIVEMessidor' => 'Messidoren',
  'Mon' => 'Pon',
  'Monday' => 'Ponedelnik',
  'Mother’s family with %s' => 'Semejstvoto na majkata so %s',
  'Mother’s family with an unknown individual' => 'Semejstvoto na majkata so nepoznata lichnost',
  'Name' => 'Ime i prezime',
  'RepositoryName' => 'Ime i prezime',
  'NOMINATIVENivose' => 'Nivos',
  'Note' => 'Zabeleshka',
  'Abbreviation for NovemberNov' => 'Nov',
  'GENITIVENovember' => 'Noemvri',
  'INSTRUMENTALNovember' => 'Noemvri',
  'LOCATIVENovember' => 'Noemvri',
  'NOMINATIVENovember' => 'Noemvri',
  'Number of given names' => 'Broj na dadeni iminja',
  'Abbreviation for OctoberOct' => 'Okt',
  'GENITIVEOctober' => 'Oktomvri',
  'INSTRUMENTALOctober' => 'Oktomvri',
  'LOCATIVEOctober' => 'Oktomvri',
  'NOMINATIVEOctober' => 'Oktomvri',
  'On this day' => 'Na ovoj den',
  'On this day…' => 'Na ovoj den…',
  'Palette' => 'Boja na temata',
  'Place of birth' => 'Mesto na ragjanje',
  'Place of death' => 'Mesto na smrt',
  'NOMINATIVEPluviose' => 'Pluvios',
  'NOMINATIVEPrairial' => 'Prairalen',
  'Privacy policy' => 'Politika za privatnost',
  'Female pedigreeRada' => 'Radah',
  'Male pedigreeRada' => 'Radah',
  'Re-order families' => 'Sortiraj gi semejstvata',
  'Relationship to father' => 'Odnos so tatkoto',
  'Relationship to mother' => 'Relacija so majkata',
  'Request a new password' => 'Pobarajte nova lozinka',
  'Request a new user account' => 'Registriraj se',
  'Sat' => 'Sab',
  'Saturday' => 'Sabota',
  'Female pedigreeSealing' => 'Zagrizhuvach',
  'Male pedigreeSealing' => 'Zapechatuvanje',
  'Abbreviation for SeptemberSep' => 'Sep',
  'GENITIVESeptember' => 'Septemvri',
  'INSTRUMENTALSeptember' => 'Septemvri',
  'LOCATIVESeptember' => 'Septemvri',
  'NOMINATIVESeptember' => 'Septemvri',
  'Shared note' => 'Spodelena zabelehska',
  'Show a privacy policy.' => 'Pokazhete gi pravilata za privatnost.',
  'Show only females.' => 'Prikazhi samo zheni.',
  'Show only males.' => 'Prikazhi samo mazhi.',
  'Show to managers' => 'Pokazhi na manadjeri',
  'Show to members' => 'Pokazhi na chlenovite',
  'Show to visitors' => 'Pokazhi na posetitelite',
  'Sign in' => 'Najavi se',
  'Sign-in and registration' => 'Najavuvanje i registracija',
  'Statistics' => 'Statistika',
  'Sun' => 'Ned',
  'Sunday' => 'Nedela',
  'Surname' => 'Prezime',
  'NOMINATIVEThermidor' => 'Thermidoren',
  'This family tree was last updated on %s.' => 'Ova semejno steblo posleden pat e azhurirano na %s.',
  'This page has been viewed %s time.' . "\0" . 'This page has been viewed %s times.' => 'Ovaa stranica e pregledana %s pat.' . "\0" . 'Ovaa stranica e pregledana %s pati.',
  'Thu' => 'Che',
  'Thursday' => 'Chetvrtok',
  'Top %s given name' . "\0" . 'Top %s given names' => 'Vrvno %s ime' . "\0" . 'Vrvni %s iminja',
  'Top given names' => 'Najmnogu davani iminja',
  'Top surname' => 'Vrvno prezime',
  'Top surnames' => 'Vrvni preziminja',
  'Total given names' => 'Vkupno dadeni iminja',
  'Tue' => 'Vto',
  'Tuesday' => 'Vtornik',
  'unknown sexUnknown' => 'Nepoznato',
  'Username' => 'Korisnichko ime',
  'NOMINATIVEVendemiaire' => 'Vendemier',
  'NOMINATIVEVentose' => 'Ventos',
  'View this day' => 'Prikazhi go ovoj den',
  'View this family' => 'Poglednigo ova semejstvo',
  'View this month' => 'Prikazhigo ovoj mesec',
  'View this year' => 'Prikazhija ova godina',
  'Wed' => 'Sre',
  'Wednesday' => 'Sreda',
  'Welcome to this genealogy website' => 'Dobredojdovte na ovaa web-stranica za genealogija',
  'You can apply for an account using the link below.' => 'Mozhete da aplicirate za smetka koristejkji go linkot podolu.',
  'You need to be an authorized user to access this website.' => 'Treba da bidete ovlasten korisnik za da pristapite do ovaa web-stranica.',
  'about %s' => 'okolu %s',
  'after %s' => 'posle %s',
  'before %s' => 'pred %s',
  'between %s and %s' => 'pomegju %s i %s',
  'birth name' => 'rodeno ime',
  'calculated %s' => 'presmetano %s',
  'estimated %s' => 'proceneto %s',
  'father' => 'tatko',
  'from %s' => 'od %s',
  'from %s to %s' => 'od %s do %s',
  'herself' => 'smata taa',
  'himself' => 'samiot toj',
  'interpreted %s (%s)' => 'protolkuvani %s (%s)',
  'mother' => 'majka',
  'sex' => 'pol',
  'to %s' => 'do %s',
  'father’s brotheruncle' => 'striko/vujko',
  'yes' => 'da',
  'Unknown given name…' => '…',
  'Unknown surname…' => '…',
);
